@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Role::HelpAsText 2.148;
+package Config::Model::Role::HelpAsText 2.150;
 
 # ABSTRACT: Translate element help from pod to text
 
@@ -16,14 +16,15 @@ use strict;
 use warnings;
 use Pod::Text;
 use Pod::Simple 3.23;
-use 5.10.1;
+use v5.20;
+
+use feature qw/postderef signatures/;
+no warnings qw/experimental::postderef experimental::signatures/;
 
 requires('get_help');
 
-sub get_help_as_text {
-    my $self = shift;
-
-    my $pod = $self->get_help(@_) ;
+sub get_help_as_text ($self, @args) {
+    my $pod = $self->get_help(@args) ;
     return unless defined $pod;
 
     my $parser = Pod::Text->new(
@@ -57,7 +58,7 @@ Config::Model::Role::HelpAsText - Translate element help from pod to text
 
 =head1 VERSION
 
-version 2.148
+version 2.150
 
 =head1 SYNOPSIS
 
